@@ -1,7 +1,7 @@
 /*
 * libslack - http://libslack.org/
 *
-* Copyright (C) 1999-2001 raf <raf@raf.org>
+* Copyright (C) 1999-2002 raf <raf@raf.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -18,32 +18,39 @@
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * or visit http://www.gnu.org/copyleft/gpl.html
 *
-* 20010215 raf <raf@raf.org>
+* 20020916 raf <raf@raf.org>
 */
 
 #ifndef LIBSLACK_LIB_H
 #define LIBSLACK_LIB_H
 
+#include <slack/std.h>
+
+#include <slack/agent.h>
 #include <slack/daemon.h>
 #include <slack/err.h>
 #include <slack/fio.h>
 #include <slack/hsort.h>
 #include <slack/lim.h>
+#include <slack/link.h>
 #include <slack/list.h>
+#include <slack/locker.h>
 #include <slack/map.h>
 #include <slack/mem.h>
 #include <slack/msg.h>
 #include <slack/net.h>
 #include <slack/prog.h>
 #include <slack/prop.h>
+#include <slack/pseudo.h>
 #include <slack/sig.h>
 #include <slack/str.h>
-#include <slack/thread.h>
 
-#ifdef NEEDS_GETOPT
-#include <slack/getopt.h>
-#else
-#include <getopt.h>
+#ifndef HAVE_SNPRINTF
+#include <slack/snprintf.h>
+#endif
+
+#ifndef HAVE_VSSCANF
+#include <slack/vsscanf.h>
 #endif
 
 #endif
